objectFromData method
Shortcut that creates a ByteData view and passes it to objectFromFB.
Implementation
T objectFromData(Store store, Pointer<Uint8> data, int size) {
// There has been a performance improvement in the past using memcpy for
// small buffers, but this is not longer faster than asTypedList.
// See /benchmark/bin/native_pointers.dart.
final uInt8List = data.asTypedList(size);
final byteData = ByteData.view(
uInt8List.buffer,
uInt8List.offsetInBytes,
size,
);
return objectFromFB(store, byteData);
}