addNetworkHandle method

void addNetworkHandle(
  1. int networkHandle
)

Adds a callback-driven mesh network created with the C mesh network API (an OBX_mesh_network, e.g. by the MeshNetwork class of ObjectBox Swift) to a mesh config.

networkHandle is the address of the OBX_mesh_network handle. The mesh options only add their own reference to the network when built; whoever created the handle keeps owning (and eventually freeing) it.

Implementation

void addNetworkHandle(int networkHandle) {
  _networkHandles.add(networkHandle);
}