Uuid constant

int const Uuid

A UUID (Universally Unique Identifier) as defined by RFC 9562. ObjectBox uses the UUIDv7 scheme (timestamp + random) to create new UUIDs. UUIDv7 is a good choice for database keys as it's mostly sequential and encodes a timestamp. However, if keys are used externally, consider UuidV4 for better privacy by not exposing any time information. Representing type: ByteVector Encoding: 1:1 binary representation (16 bytes)

Implementation

static const Uuid = 102;