InternalSyncAccess class
Internal access for platform integrations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
addNetworkInternalHandle(
MeshConfig mesh, int networkInternalHandle) → void - Adds a platform-specific native network to a mesh config.
-
createMeshConfig(
String meshId, {int? maxConnectionCount, int? backoffMillis, int? evictionBackoffMillis, int? randomSeed, int? requestTimeoutMillis, int? advertisingDelayMillis, int? connectDelayMillis, int? initialDiscoveryDurationSeconds, int? discoveryDurationSeconds, int? discoveryPauseSeconds, int? discoveryPauseJitterSeconds, int? txLogBatchSizeKb, int? txLogBatchMaxCount}) → MeshConfig - Creates a mesh sync configuration. See MeshConfig field documentation for details on each option.