SYNC_PRECEDENCE constant

int const SYNC_PRECEDENCE

Marks a Long (64-bit integer) property as the "sync precedence" to customize Sync conflict resolution. Developer-assigned precedence values are then used to resolve conflicts via "higher precedence wins". Defining and assigning precedence values are completely in the hands of the developer (the ObjectBox user). There can be only one sync precedence per sync entity type. Typically, it is combined with a sync clock, with the latter being the tie-breaker for equal precedence values.

Implementation

static const int SYNC_PRECEDENCE = 262144;